"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DayWrapper = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const UI_1 = require("../UI");
const focus_1 = require("../contexts/focus");
const modifiers_1 = require("../contexts/modifiers");
const props_1 = require("../contexts/props");
const selection_1 = require("../contexts/selection");
const debounce_1 = require("../helpers/debounce");
const getClassNamesForModifiers_1 = require("../helpers/getClassNamesForModifiers");
const getStyleForModifiers_1 = require("../helpers/getStyleForModifiers");
const Day_1 = require("./Day");
/**
 * Provides a `Day` the day state and the html attributes. Developers may use a
 * `Day` component without the need to use hooks.
 *
 * @internal
 */
function DayWrapper(props) {
    var _a;
    const cellRef = (0, react_1.useRef)(null);
    const { classNames, components, dir, formatters: { formatDay }, locale, mode, modifiersClassNames = {}, modifiersStyles = {}, onDayFocus, onDayBlur, onDayClick, onDayKeyDown, onDayKeyPress, onDayKeyUp, onDayMouseEnter, onDayMouseLeave, onDayPointerEnter, onDayPointerLeave, onDayTouchCancel, onDayTouchEnd, onDayTouchMove, onDayTouchStart, styles = {} } = (0, props_1.useProps)();
    const { setSelected } = (0, selection_1.useSelection)();
    const { getModifiers } = (0, modifiers_1.useModifiers)();
    const { autoFocusTarget, focusedDay, focus, blur, focusDayBefore, focusDayAfter, focusWeekBefore, focusWeekAfter, focusMonthBefore, focusMonthAfter, focusYearBefore, focusYearAfter, focusStartOfWeek, focusEndOfWeek } = (0, focus_1.useFocus)();
    const modifiers = getModifiers(props.day);
    const onClick = (e) => {
        if (modifiers.disabled) {
            e.preventDefault();
            e.stopPropagation();
            return;
        }
        setSelected(props.day.date, modifiers, e);
        if (modifiers.focusable) {
            focus(props.day);
        }
        onDayClick === null || onDayClick === void 0 ? void 0 : onDayClick(props.day.date, modifiers, e);
    };
    const onFocus = (e) => {
        focus(props.day);
        onDayFocus === null || onDayFocus === void 0 ? void 0 : onDayFocus(props.day.date, modifiers, e);
    };
    const onBlur = (e) => {
        blur();
        onDayBlur === null || onDayBlur === void 0 ? void 0 : onDayBlur(props.day.date, modifiers, e);
    };
    const onMouseEnter = (e) => {
        onDayMouseEnter === null || onDayMouseEnter === void 0 ? void 0 : onDayMouseEnter(props.day.date, modifiers, e);
    };
    const onMouseLeave = (e) => {
        onDayMouseLeave === null || onDayMouseLeave === void 0 ? void 0 : onDayMouseLeave(props.day.date, modifiers, e);
    };
    const onPointerEnter = (e) => {
        onDayPointerEnter === null || onDayPointerEnter === void 0 ? void 0 : onDayPointerEnter(props.day.date, modifiers, e);
    };
    const onPointerLeave = (e) => {
        onDayPointerLeave === null || onDayPointerLeave === void 0 ? void 0 : onDayPointerLeave(props.day.date, modifiers, e);
    };
    const onTouchCancel = (e) => {
        onDayTouchCancel === null || onDayTouchCancel === void 0 ? void 0 : onDayTouchCancel(props.day.date, modifiers, e);
    };
    const onTouchEnd = (e) => {
        onDayTouchEnd === null || onDayTouchEnd === void 0 ? void 0 : onDayTouchEnd(props.day.date, modifiers, e);
    };
    const onTouchMove = (e) => {
        onDayTouchMove === null || onDayTouchMove === void 0 ? void 0 : onDayTouchMove(props.day.date, modifiers, e);
    };
    const onTouchStart = (e) => {
        onDayTouchStart === null || onDayTouchStart === void 0 ? void 0 : onDayTouchStart(props.day.date, modifiers, e);
    };
    const onKeyUp = (e) => {
        onDayKeyUp === null || onDayKeyUp === void 0 ? void 0 : onDayKeyUp(props.day.date, modifiers, e);
    };
    const onKeyPress = (e) => {
        onDayKeyPress === null || onDayKeyPress === void 0 ? void 0 : onDayKeyPress(props.day.date, modifiers, e);
    };
    const onKeyDown = (e) => {
        switch (e.key) {
            case "ArrowLeft":
                e.preventDefault();
                e.stopPropagation();
                dir === "rtl" ? focusDayAfter() : focusDayBefore();
                break;
            case "ArrowRight":
                e.preventDefault();
                e.stopPropagation();
                dir === "rtl" ? focusDayBefore() : focusDayAfter();
                break;
            case "ArrowDown":
                e.preventDefault();
                e.stopPropagation();
                focusWeekAfter();
                break;
            case "ArrowUp":
                e.preventDefault();
                e.stopPropagation();
                focusWeekBefore();
                break;
            case " ":
            case "Enter":
                e.preventDefault();
                e.stopPropagation();
                setSelected(props.day.date, modifiers, e);
                break;
            case "PageUp":
                e.preventDefault();
                e.stopPropagation();
                e.shiftKey ? focusYearBefore() : focusMonthBefore();
                break;
            case "PageDown":
                e.preventDefault();
                e.stopPropagation();
                e.shiftKey ? focusYearAfter() : focusMonthAfter();
                break;
            case "Home":
                e.preventDefault();
                e.stopPropagation();
                focusStartOfWeek();
                break;
            case "End":
                e.preventDefault();
                e.stopPropagation();
                focusEndOfWeek();
                break;
        }
        onDayKeyDown === null || onDayKeyDown === void 0 ? void 0 : onDayKeyDown(props.day.date, modifiers, e);
    };
    const isAutoFocusTarget = Boolean(autoFocusTarget === null || autoFocusTarget === void 0 ? void 0 : autoFocusTarget.isEqualTo(props.day));
    const isFocused = Boolean(focusedDay === null || focusedDay === void 0 ? void 0 : focusedDay.isEqualTo(props.day));
    const isInteractive = mode !== "default" || Boolean(onDayClick);
    const style = (0, getStyleForModifiers_1.getStyleForModifiers)(modifiers, modifiersStyles, styles);
    const classNameForModifiers = (0, getClassNamesForModifiers_1.getClassNamesForModifiers)(modifiers, modifiersClassNames, classNames);
    const className = [classNames[UI_1.UI.Day], ...classNameForModifiers];
    if (isFocused) {
        className.push(classNames[UI_1.DayModifier.focused]);
    }
    const htmlAttributes = {
        role: "gridcell",
        className: className.join(" "),
        style,
        tabIndex: isFocused || isAutoFocusTarget ? 0 : -1,
        ["aria-colindex"]: props["aria-colindex"],
        ["aria-disabled"]: modifiers.disabled || undefined,
        ["aria-hidden"]: modifiers.hidden || undefined,
        ["aria-selected"]: modifiers.selected || undefined,
        onClick: isInteractive ? onClick : undefined,
        onBlur,
        onFocus,
        onKeyDown,
        onKeyPress: (0, debounce_1.debounce)(onKeyPress, 300),
        onKeyUp,
        onMouseEnter,
        onMouseLeave,
        onPointerEnter,
        onPointerLeave,
        onTouchCancel,
        onTouchEnd,
        onTouchMove,
        onTouchStart,
        ref: cellRef
    };
    (0, react_1.useEffect)(() => {
        if (!cellRef.current)
            return; // no element to focus
        if (!focusedDay)
            return; // no day to focus
        if (!props.day.isEqualTo(focusedDay))
            return; // not this day`
        if (modifiers.disabled || modifiers.hidden)
            return; // cannot focus
        cellRef.current.focus();
    }, [focusedDay, modifiers.disabled, modifiers.hidden, props.day]);
    const Day = (_a = components === null || components === void 0 ? void 0 : components.Day) !== null && _a !== void 0 ? _a : Day_1.Day;
    return ((0, jsx_runtime_1.jsx)(Day, { day: props.day, modifiers: modifiers, htmlAttributes: htmlAttributes, children: formatDay(props.day.date, { locale }) }));
}
exports.DayWrapper = DayWrapper;
//# sourceMappingURL=DayWrapper.js.map