"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useFocus = exports.FocusProvider = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const getNextFocus_1 = require("../helpers/getNextFocus");
const calendar_1 = require("./calendar");
const modifiers_1 = require("./modifiers");
const props_1 = require("./props");
const focusContext = (0, react_1.createContext)(undefined);
/** @private */
function FocusProvider(props) {
    var _a;
    const { goToDay, isDayDisplayed } = (0, calendar_1.useCalendar)();
    const { autoFocus = false, ...dayPickerProps } = (0, props_1.useProps)();
    const { calendarModifiers } = (0, modifiers_1.useModifiers)();
    const [focused, setFocused] = (0, react_1.useState)();
    const [lastFocused, setLastFocused] = (0, react_1.useState)();
    const [initiallyFocused, setInitiallyFocused] = (0, react_1.useState)(false);
    const autoFocusTarget = (focused !== null && focused !== void 0 ? focused : (lastFocused && isDayDisplayed(lastFocused)))
        ? lastFocused
        : (_a = calendarModifiers.selected[0]) !== null && _a !== void 0 ? _a : 
        // TOFIX: possible bug here selecting a today date when disabled
        // calendarModifiers.today[0] ?? // autofocus today
        calendarModifiers.focusable[0]; // otherwise autofocus the first focusable day;
    // Focus the focus target when autoFocus is passed in
    (0, react_1.useEffect)(() => {
        if (!autoFocus)
            return;
        if (!autoFocusTarget)
            return;
        if (!initiallyFocused)
            return;
        setInitiallyFocused(true);
        setFocused(autoFocusTarget);
    }, [autoFocus, autoFocusTarget, focused, initiallyFocused]);
    function blur() {
        setLastFocused(focused);
        setFocused(undefined);
    }
    function moveFocus(moveBy, moveDir) {
        if (!focused)
            return;
        const nextFocus = (0, getNextFocus_1.getNextFocus)(moveBy, moveDir, focused, dayPickerProps);
        if (!nextFocus)
            return;
        goToDay(nextFocus);
        setFocused(nextFocus);
    }
    const value = {
        autoFocusTarget,
        initiallyFocused,
        focusedDay: focused,
        blur,
        focus: setFocused,
        focusDayAfter: () => moveFocus("day", "after"),
        focusDayBefore: () => moveFocus("day", "before"),
        focusWeekAfter: () => moveFocus("week", "after"),
        focusWeekBefore: () => moveFocus("week", "before"),
        focusMonthBefore: () => moveFocus("month", "before"),
        focusMonthAfter: () => moveFocus("month", "after"),
        focusYearBefore: () => moveFocus("year", "before"),
        focusYearAfter: () => moveFocus("year", "after"),
        focusStartOfWeek: () => moveFocus("startOfWeek", "before"),
        focusEndOfWeek: () => moveFocus("endOfWeek", "after")
    };
    return ((0, jsx_runtime_1.jsx)(focusContext.Provider, { value: value, children: props.children }));
}
exports.FocusProvider = FocusProvider;
/**
 * Share the focused day and the methods to move the focus.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function useFocus() {
    const context = (0, react_1.useContext)(focusContext);
    if (!context) {
        throw new Error("useFocus must be used within a FocusProvider");
    }
    return context;
}
exports.useFocus = useFocus;
//# sourceMappingURL=focus.js.map