"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useProps = exports.PropsProvider = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const getClassNames_1 = require("../helpers/getClassNames");
const getDataAttributes_1 = require("../helpers/getDataAttributes");
const getFormatters_1 = require("../helpers/getFormatters");
const getFromToDate_1 = require("../helpers/getFromToDate");
const getLabels_1 = require("../helpers/getLabels");
const propsContext = (0, react_1.createContext)(null);
/**
 * Provide the props to the DayPicker components. Must be used as root of the
 * other providers.
 *
 * @private
 */
const PropsProvider = (props) => {
    var _a, _b, _c, _d, _e, _f, _g;
    const reactId = (0, react_1.useId)();
    const { children, ...restProps } = props;
    const { fromDate, toDate } = (0, getFromToDate_1.getFromToDate)(props);
    const context = {
        ...restProps,
        classNames: (0, getClassNames_1.getClassNames)(props.classNames),
        dataAttributes: (0, getDataAttributes_1.getDataAttributes)(props),
        formatters: (0, getFormatters_1.getFormatters)(props.formatters),
        fromDate,
        id: (_a = props.id) !== null && _a !== void 0 ? _a : reactId,
        labels: (0, getLabels_1.getLabels)(props.labels),
        required: "required" in props ? (_b = props.required) !== null && _b !== void 0 ? _b : false : false,
        min: "min" in props ? (_c = props.min) !== null && _c !== void 0 ? _c : undefined : undefined,
        max: "max" in props ? (_d = props.max) !== null && _d !== void 0 ? _d : undefined : undefined,
        mode: (_e = props.mode) !== null && _e !== void 0 ? _e : "default",
        numberOfMonths: (_f = props.numberOfMonths) !== null && _f !== void 0 ? _f : 1,
        today: (_g = props.today) !== null && _g !== void 0 ? _g : new Date(),
        toDate,
        selected: "selected" in props ? props.selected : undefined,
        defaultSelected: "defaultSelected" in props ? props.defaultSelected : undefined,
        onSelect: "onSelect" in props ? props.onSelect : undefined
    };
    return ((0, jsx_runtime_1.jsx)(propsContext.Provider, { value: context, children: children }));
};
exports.PropsProvider = PropsProvider;
/**
 * Access to the props passed to DayPicker.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
function useProps() {
    const context = (0, react_1.useContext)(propsContext);
    if (!context) {
        throw new Error("useDayPicker() must be used within a `<dayPickerContext.Provider/>`.");
    }
    return context;
}
exports.useProps = useProps;
//# sourceMappingURL=props.js.map