import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { UI, CalendarFlag } from "../UI";
import { useCalendar } from "../contexts/calendar";
import { useProps } from "../contexts/props";
import { Footer as DefaultFooter } from "./Footer";
import { Month as DefaultMonth } from "./Month";
import { Months as DefaultMonths } from "./Months";
import { Nav as DefaultNav } from "./Nav";
/**
 * Render the DayPicker Calendar with navigation and the month grids.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function Calendar() {
    var _a, _b, _c, _d;
    const { className, classNames, components, dataAttributes, dir, footer, hideNavigation, hideWeekdayRow, id, lang, nonce, numberOfMonths, showWeekNumber, style, styles, title } = useProps();
    const calendar = useCalendar();
    // Apply classnames according to props
    const cssClassNames = [classNames[UI.Calendar]];
    if (className) {
        cssClassNames.push(className);
    }
    if (numberOfMonths > 1) {
        cssClassNames.push(classNames[CalendarFlag.hasMultipleMonths]);
    }
    if (showWeekNumber) {
        cssClassNames.push(classNames[CalendarFlag.hasWeekNumbers]);
    }
    if (hideWeekdayRow) {
        cssClassNames.push(classNames[CalendarFlag.noWeekdays]);
    }
    const Nav = (_a = components === null || components === void 0 ? void 0 : components.Nav) !== null && _a !== void 0 ? _a : DefaultNav;
    const Months = (_b = components === null || components === void 0 ? void 0 : components.Months) !== null && _b !== void 0 ? _b : DefaultMonths;
    const Month = (_c = components === null || components === void 0 ? void 0 : components.Month) !== null && _c !== void 0 ? _c : DefaultMonth;
    const Footer = (_d = components === null || components === void 0 ? void 0 : components.Footer) !== null && _d !== void 0 ? _d : DefaultFooter;
    return (_jsxs("div", { className: cssClassNames.join(" "), style: { ...styles === null || styles === void 0 ? void 0 : styles[UI.Calendar], ...style }, dir: dir, id: id, lang: lang, nonce: nonce, title: title, ...dataAttributes, children: [_jsx(Months, { className: classNames[UI.Months], style: styles === null || styles === void 0 ? void 0 : styles[UI.Months], children: calendar.months.map((month, i) => (_jsx(Month, { "aria-labelledby": id, index: i, month: month }, i))) }), !hideNavigation && _jsx(Nav, {}), footer && (_jsx(Footer, { className: classNames[UI.Footer], style: styles === null || styles === void 0 ? void 0 : styles[UI.Footer], children: footer }))] }));
}
//# sourceMappingURL=Calendar.js.map