import { jsx as _jsx } from "react/jsx-runtime";
import { setMonth } from "date-fns/setMonth";
import { startOfMonth } from "date-fns/startOfMonth";
import { UI } from "../UI";
import { useCalendar } from "../contexts/calendar";
import { useProps } from "../contexts/props";
import { Dropdown as DefaultDropdown } from "./Dropdown";
/**
 * Render the dropdown to change the month.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function MonthsDropdown(props) {
    var _a;
    const { classNames, components, labels: { labelMonthDropdown } } = useProps();
    const { dropdownOptions: dropdown, goToMonth } = useCalendar();
    const Dropdown = (_a = components === null || components === void 0 ? void 0 : components.Dropdown) !== null && _a !== void 0 ? _a : DefaultDropdown;
    const handleChange = (e) => {
        const selectedMonth = Number(e.target.value);
        const month = setMonth(startOfMonth(props.month.date), selectedMonth);
        goToMonth(month);
    };
    return (_jsx(Dropdown, { name: "month", "aria-label": labelMonthDropdown(), rootClassName: classNames[UI.MonthsDropdown], options: dropdown.months, value: props.month.date.getMonth(), onChange: handleChange }));
}
//# sourceMappingURL=MonthsDropdown.js.map