import { jsx as _jsx } from "react/jsx-runtime";
import { setYear } from "date-fns/setYear";
import { startOfMonth } from "date-fns/startOfMonth";
import { UI } from "../UI";
import { useCalendar } from "../contexts/calendar";
import { useProps } from "../contexts/props";
import { Dropdown as DefaultDropdown } from "./Dropdown";
/**
 * Render the dropdown to change the year.
 *
 * Use the `components` prop to swap this component with a custom one.
 *
 * @group Components
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function YearsDropdown(props) {
    var _a;
    const { classNames, components, labels: { labelYearDropdown } } = useProps();
    const { dropdownOptions: dropdown, goToMonth } = useCalendar();
    const handleChange = (e) => {
        const month = setYear(startOfMonth(props.month.date), Number(e.target.value));
        goToMonth(month);
    };
    const Dropdown = (_a = components === null || components === void 0 ? void 0 : components.Dropdown) !== null && _a !== void 0 ? _a : DefaultDropdown;
    return (_jsx(Dropdown, { name: "year", "aria-label": labelYearDropdown(), rootClassName: classNames[UI.YearsDropdown], options: dropdown.years, value: props.month.date.getFullYear(), onChange: handleChange }));
}
//# sourceMappingURL=YearsDropdown.js.map