import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useContext, useEffect, useState } from "react";
import { getNextFocus } from "../helpers/getNextFocus";
import { useCalendar } from "./calendar";
import { useModifiers } from "./modifiers";
import { useProps } from "./props";
const focusContext = createContext(undefined);
/** @private */
export function FocusProvider(props) {
    var _a;
    const { goToDay, isDayDisplayed } = useCalendar();
    const { autoFocus = false, ...dayPickerProps } = useProps();
    const { calendarModifiers } = useModifiers();
    const [focused, setFocused] = useState();
    const [lastFocused, setLastFocused] = useState();
    const [initiallyFocused, setInitiallyFocused] = useState(false);
    const autoFocusTarget = (focused !== null && focused !== void 0 ? focused : (lastFocused && isDayDisplayed(lastFocused)))
        ? lastFocused
        : (_a = calendarModifiers.selected[0]) !== null && _a !== void 0 ? _a : 
        // TOFIX: possible bug here selecting a today date when disabled
        // calendarModifiers.today[0] ?? // autofocus today
        calendarModifiers.focusable[0]; // otherwise autofocus the first focusable day;
    // Focus the focus target when autoFocus is passed in
    useEffect(() => {
        if (!autoFocus)
            return;
        if (!autoFocusTarget)
            return;
        if (!initiallyFocused)
            return;
        setInitiallyFocused(true);
        setFocused(autoFocusTarget);
    }, [autoFocus, autoFocusTarget, focused, initiallyFocused]);
    function blur() {
        setLastFocused(focused);
        setFocused(undefined);
    }
    function moveFocus(moveBy, moveDir) {
        if (!focused)
            return;
        const nextFocus = getNextFocus(moveBy, moveDir, focused, dayPickerProps);
        if (!nextFocus)
            return;
        goToDay(nextFocus);
        setFocused(nextFocus);
    }
    const value = {
        autoFocusTarget,
        initiallyFocused,
        focusedDay: focused,
        blur,
        focus: setFocused,
        focusDayAfter: () => moveFocus("day", "after"),
        focusDayBefore: () => moveFocus("day", "before"),
        focusWeekAfter: () => moveFocus("week", "after"),
        focusWeekBefore: () => moveFocus("week", "before"),
        focusMonthBefore: () => moveFocus("month", "before"),
        focusMonthAfter: () => moveFocus("month", "after"),
        focusYearBefore: () => moveFocus("year", "before"),
        focusYearAfter: () => moveFocus("year", "after"),
        focusStartOfWeek: () => moveFocus("startOfWeek", "before"),
        focusEndOfWeek: () => moveFocus("endOfWeek", "after")
    };
    return (_jsx(focusContext.Provider, { value: value, children: props.children }));
}
/**
 * Share the focused day and the methods to move the focus.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function useFocus() {
    const context = useContext(focusContext);
    if (!context) {
        throw new Error("useFocus must be used within a FocusProvider");
    }
    return context;
}
//# sourceMappingURL=focus.js.map