import { jsx as _jsx } from "react/jsx-runtime";
import { createContext, useContext, useId } from "react";
import { getClassNames } from "../helpers/getClassNames";
import { getDataAttributes } from "../helpers/getDataAttributes";
import { getFormatters } from "../helpers/getFormatters";
import { getFromToDate } from "../helpers/getFromToDate";
import { getLabels } from "../helpers/getLabels";
const propsContext = createContext(null);
/**
 * Provide the props to the DayPicker components. Must be used as root of the
 * other providers.
 *
 * @private
 */
export const PropsProvider = (props) => {
    var _a, _b, _c, _d, _e, _f, _g;
    const reactId = useId();
    const { children, ...restProps } = props;
    const { fromDate, toDate } = getFromToDate(props);
    const context = {
        ...restProps,
        classNames: getClassNames(props.classNames),
        dataAttributes: getDataAttributes(props),
        formatters: getFormatters(props.formatters),
        fromDate,
        id: (_a = props.id) !== null && _a !== void 0 ? _a : reactId,
        labels: getLabels(props.labels),
        required: "required" in props ? (_b = props.required) !== null && _b !== void 0 ? _b : false : false,
        min: "min" in props ? (_c = props.min) !== null && _c !== void 0 ? _c : undefined : undefined,
        max: "max" in props ? (_d = props.max) !== null && _d !== void 0 ? _d : undefined : undefined,
        mode: (_e = props.mode) !== null && _e !== void 0 ? _e : "default",
        numberOfMonths: (_f = props.numberOfMonths) !== null && _f !== void 0 ? _f : 1,
        today: (_g = props.today) !== null && _g !== void 0 ? _g : new Date(),
        toDate,
        selected: "selected" in props ? props.selected : undefined,
        defaultSelected: "defaultSelected" in props ? props.defaultSelected : undefined,
        onSelect: "onSelect" in props ? props.onSelect : undefined
    };
    return (_jsx(propsContext.Provider, { value: context, children: children }));
};
/**
 * Access to the props passed to DayPicker.
 *
 * Use this hook from the custom components passed via the `components` prop.
 *
 * @group Hooks
 * @see https://react-day-picker.js.org/advanced-guides/custom-components
 */
export function useProps() {
    const context = useContext(propsContext);
    if (!context) {
        throw new Error("useDayPicker() must be used within a `<dayPickerContext.Provider/>`.");
    }
    return context;
}
//# sourceMappingURL=props.js.map